@@ -90,12 +90,32 @@ class cognet:
                     v=np.append(v,val)
                 variation_weight.append(entropy(v,base=len(v)))
             self.variation_weight = variation_weight
-            
+    
+    def load_from_dataformatter(self, 
+                                data_obj,
+                                key):
+        """read in either train or test data, specified by key, from data obj
+
+        Args:
+          data_obj (class): instance of dataformatter class
+          key (str): 'all', 'train', or 'test', corresponding to sample type
+        """
+        featurenames, samples = data_obj.samples(key)
+        if any(x is not None for x in [self.features, self.samples]):
+            print("replacing original features/samples with dataformatter data")
+        self.cols = np.array(model.features)
+        self.features = pd.DataFrame(columns=self.cols)
+        self.samples = pd.DataFrame(samples,columns=self.features)
+        self.all_samples = self.samples
+        self.samples_as_strings = self.samples[self.cols].fillna('').values.astype(str)[:]
+        self.s_null=['']*len(self.samples_as_strings[0])
+        return featurenames, samples
+
     def load_data(self,
-                year,
-                features_by_year,
-                samples,
-                qnet):
+                  year,
+                  features_by_year,
+                  samples,
+                  qnet):
         '''load cols, features, samples, and qnet.
 
         Args:
@@ -459,7 +479,7 @@ class cognet:
             EFILE = out_dir + PREF + '_E_' +yr
             DFILE = out_dir + PREF + '_D_' +yr
 
-            pd.read_csv(FILE,header=None).to_csv(DATAFILE,sep=' ',header=None,index=None)
+            pd.read_csv(FILE, index_col=0).to_csv(DATAFILE,sep=' ',header=None,index=None)
             STR=EMBED+' -f '+DATAFILE+' -E '+EFILE+' -D '+DFILE
             subprocess.call(STR,shell=True)
             if pca_model:
@@ -658,6 +678,9 @@ class cognet:
         Args:
           output_file (str): directory and/or file for output
           n_jobs (int): number of jobs for pdqm
+
+        Returns:
+          pandas.DataFrame
         '''
         manager = mp.Manager()
         return_dict = manager.dict()
@@ -679,7 +702,7 @@ class cognet:
         result=pd.DataFrame(result,columns=cols).to_csv(output_file)
         
         self.dissonance_file = output_file
-        return return_dict
+        return pd.DataFrame(return_dict.copy())
     
     def __choose_one(self,
                 X):
